==> monaco-vscode-authentication-service-override-12.0.0.tgz: package/index.js <==

import 'vscode/vscode/vs/editor/standalone/browser/standaloneServices';
import { SyncDescriptor } from 'vscode/vscode/vs/platform/instantiation/common/descriptors';
import { IAuthenticationService, IAuthenticationExtensionsService } from 'vscode/vscode/vs/workbench/services/authentication/common/authentication.service';
import { AuthenticationService } from '@codingame/monaco-vscode-3607c442-ae7a-594b-b840-038378c24fef-common/vscode/vs/workbench/services/authentication/browser/authenticationService';
import { AuthenticationAccessService } from './vscode/src/vs/workbench/services/authentication/browser/authenticationAccessService.js';
import { AuthenticationUsageService } from './vscode/src/vs/workbench/services/authentication/browser/authenticationUsageService.js';
import { AuthenticationExtensionsService } from './vscode/src/vs/workbench/services/authentication/browser/authenticationExtensionsService.js';
import { IAuthenticationAccessService } from 'vscode/vscode/vs/workbench/services/authentication/browser/authenticationAccessService.service';
import { IAuthenticationUsageService } from 'vscode/vscode/vs/workbench/services/authentication/browser/authenticationUsageService.service';

function getServiceOverride() {
    return {
        [IAuthenticationService.toString()]: new SyncDescriptor(AuthenticationService, [], true),
        [IAuthenticationAccessService.toString()]: new SyncDescriptor(AuthenticationAccessService, [], true),
        [IAuthenticationExtensionsService.toString()]: new SyncDescriptor(AuthenticationExtensionsService, [], true),
        [IAuthenticationUsageService.toString()]: new SyncDescriptor(AuthenticationUsageService, [], true)
    };
}

export { getServiceOverride as default };

==> monaco-vscode-authentication-service-override-13.1.0.tgz: package/index.js <==

import '@codingame/monaco-vscode-api/vscode/vs/editor/standalone/browser/standaloneServices';
import { SyncDescriptor } from '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/descriptors';
import { IAuthenticationService, IAuthenticationExtensionsService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/authentication/common/authentication.service';
import { AuthenticationService } from '@codingame/monaco-vscode-3607c442-ae7a-594b-b840-038378c24fef-common/vscode/vs/workbench/services/authentication/browser/authenticationService';
import { AuthenticationAccessService } from './vscode/src/vs/workbench/services/authentication/browser/authenticationAccessService.js';
import { AuthenticationUsageService } from './vscode/src/vs/workbench/services/authentication/browser/authenticationUsageService.js';
import { AuthenticationExtensionsService } from './vscode/src/vs/workbench/services/authentication/browser/authenticationExtensionsService.js';
import { IAuthenticationAccessService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/authentication/browser/authenticationAccessService.service';
import { IAuthenticationUsageService } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/authentication/browser/authenticationUsageService.service';

function getServiceOverride() {
    return {
        [IAuthenticationService.toString()]: new SyncDescriptor(AuthenticationService, [], true),
        [IAuthenticationAccessService.toString()]: new SyncDescriptor(AuthenticationAccessService, [], true),
        [IAuthenticationExtensionsService.toString()]: new SyncDescriptor(AuthenticationExtensionsService, [], true),
        [IAuthenticationUsageService.toString()]: new SyncDescriptor(AuthenticationUsageService, [], true)
    };
}

export { getServiceOverride as default };
